==> cr12g-panhuo-api-3.0.0-20210510.094220-8-sources.jar: com/ejianc/business/asset/vo/MaterialDealDetailVO.java <==
package com.ejianc.business.asset.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 报废处置子表
 * 
 * @author generator
 * 
 */
public class MaterialDealDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long pId; // 父主键
    private String materialTypeName; // 物资分类名称
    private String materialTypeCode; // 物资分类编码
    private Long materialTypeId; // 物资分类Id
    private String materialName; // 物资名称
    private String materialCode; // 物资code
    private Long materialId; // 物资Id
    private String spec; // 规格型号
    private String unit; // 计量单位
    private Long assetId; // 资产id
    private Integer assetType; // 0台车1周转材
    private String assetName; // 台车/周转材
    private String assetCode; // 编码
    private Long orgId; // 组织Id
    private String orgName; // 组织名称
    private Long projectId; // 项目id
    private String projectName; // 项目名称
    private java.math.BigDecimal ton; // 承载量（吨)
    private java.math.BigDecimal onNum; // 在场数量
    private java.math.BigDecimal dealNum; // 处置数量
    private java.math.BigDecimal dealPrice; // 处置单价
    private java.math.BigDecimal dealMoney; // 处置金额
    private Integer belongType; // 0项目1公司
    private Integer assetBelongType; // 资产归属类型
    private Long belongOrgId; // 资产归属机构id
    private String belongOrgName; // 资产归属机构名称
    

    /**
     * 父主键
     */
    public Long getPId() {
        return pId;
    }

    /**
     * 父主键
     */
    public void setPId(Long pId) {
        this.pId = pId;
    }
    /**
     * 物资分类名称
     */
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资分类名称
     */
    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物资分类编码
     */
    public String getMaterialTypeCode() {
        return materialTypeCode;
    }

    /**
     * 物资分类编码
     */
    public void setMaterialTypeCode(String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }
    /**
     * 物资分类Id
     */
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资分类Id
     */
    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资名称
     */
    public String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资code
     */
    public String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物资code
     */
    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 物资Id
     */
    public Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资Id
     */
    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 规格型号
     */
    public String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(String spec) {
        this.spec = spec;
    }
    /**
     * 计量单位
     */
    public String getUnit() {
        return unit;
    }

    /**
     * 计量单位
     */
    public void setUnit(String unit) {
        this.unit = unit;
    }
    /**
     * 资产id
     */
    public Long getAssetId() {
        return assetId;
    }

    /**
     * 资产id
     */
    public void setAssetId(Long assetId) {
        this.assetId = assetId;
    }
    /**
     * 0台车1周转材
     */
    public Integer getAssetType() {
        return assetType;
    }

    /**
     * 0台车1周转材
     */
    public void setAssetType(Integer assetType) {
        this.assetType = assetType;
    }
    /**
     * 台车/周转材
     */
    public String getAssetName() {
        return assetName;
    }

    /**
     * 台车/周转材
     */
    public void setAssetName(String assetName) {
        this.assetName = assetName;
    }
    /**
     * 编码
     */
    public String getAssetCode() {
        return assetCode;
    }

    /**
     * 编码
     */
    public void setAssetCode(String assetCode) {
        this.assetCode = assetCode;
    }
    /**
     * 组织Id
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织Id
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目id
     */
    public Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    /**
     * 承载量（吨)
     */
    public java.math.BigDecimal getTon() {
        return ton;
    }

    /**
     * 承载量（吨)
     */
    public void setTon(java.math.BigDecimal ton) {
        this.ton = ton;
    }
    /**
     * 在场数量
     */
    public java.math.BigDecimal getOnNum() {
        return onNum;
    }

    /**
     * 在场数量
     */
    public void setOnNum(java.math.BigDecimal onNum) {
        this.onNum = onNum;
    }
    /**
     * 处置数量
     */
    public java.math.BigDecimal getDealNum() {
        return dealNum;
    }

    /**
     * 处置数量
     */
    public void setDealNum(java.math.BigDecimal dealNum) {
        this.dealNum = dealNum;
    }
    /**
     * 处置单价
     */
    public java.math.BigDecimal getDealPrice() {
        return dealPrice;
    }

    /**
     * 处置单价
     */
    public void setDealPrice(java.math.BigDecimal dealPrice) {
        this.dealPrice = dealPrice;
    }
    /**
     * 处置金额
     */
    public java.math.BigDecimal getDealMoney() {
        return dealMoney;
    }

    /**
     * 处置金额
     */
    public void setDealMoney(java.math.BigDecimal dealMoney) {
        this.dealMoney = dealMoney;
    }
    /**
     * 0项目1公司
     */
    public Integer getBelongType() {
        return belongType;
    }

    /**
     * 0项目1公司
     */
    public void setBelongType(Integer belongType) {
        this.belongType = belongType;
    }
    /**
     * 资产归属类型
     */
    public Integer getAssetBelongType() {
        return assetBelongType;
    }

    /**
     * 资产归属类型
     */
    public void setAssetBelongType(Integer assetBelongType) {
        this.assetBelongType = assetBelongType;
    }
    /**
     * 资产归属机构id
     */
    public Long getBelongOrgId() {
        return belongOrgId;
    }

    /**
     * 资产归属机构id
     */
    public void setBelongOrgId(Long belongOrgId) {
        this.belongOrgId = belongOrgId;
    }
    /**
     * 资产归属机构名称
     */
    public String getBelongOrgName() {
        return belongOrgName;
    }

    /**
     * 资产归属机构名称
     */
    public void setBelongOrgName(String belongOrgName) {
        this.belongOrgName = belongOrgName;
    }
    
}

==> cr12g-panhuo-api-3.0.0-20210517.093538-47-sources.jar: com/ejianc/business/asset/vo/MaterialDealDetailVO.java <==
package com.ejianc.business.asset.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 报废处置子表
 * 
 * @author generator
 * 
 */
public class MaterialDealDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long pId; // 父主键
    private String materialTypeName; // 物资分类名称
    private String materialTypeCode; // 物资分类编码
    private Long materialTypeId; // 物资分类Id
    private String materialName; // 物资名称
    private String materialCode; // 物资code
    private Long materialId; // 物资Id
    private String spec; // 规格型号
    private String unit; // 计量单位
    private Long assetId; // 资产id
    private Integer assetType; // 0台车1周转材
    private String assetName; // 台车/周转材
    private String assetCode; // 编码
    private Long orgId; // 组织Id
    private String orgName; // 组织名称
    private Long projectId; // 项目id
    private String projectName; // 项目名称
    private java.math.BigDecimal ton; // 承载量（吨)
    private java.math.BigDecimal onNum; // 在场数量
    private java.math.BigDecimal dealNum; // 处置数量
    private java.math.BigDecimal dealPrice; // 处置单价
    private java.math.BigDecimal dealMoney; // 处置金额
    private Integer belongType; // 0项目1公司
    private Integer assetBelongType; // 资产归属类型
    private Long belongOrgId; // 资产归属机构id
    private String belongOrgName; // 资产归属机构名称
    private String materialRemark; // 备注

    public String getMaterialRemark() {
        return materialRemark;
    }

    public void setMaterialRemark(String materialRemark) {
        this.materialRemark = materialRemark;
    }

    /**
     * 父主键
     */
    public Long getPId() {
        return pId;
    }

    /**
     * 父主键
     */
    public void setPId(Long pId) {
        this.pId = pId;
    }
    /**
     * 物资分类名称
     */
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资分类名称
     */
    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物资分类编码
     */
    public String getMaterialTypeCode() {
        return materialTypeCode;
    }

    /**
     * 物资分类编码
     */
    public void setMaterialTypeCode(String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }
    /**
     * 物资分类Id
     */
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资分类Id
     */
    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资名称
     */
    public String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资code
     */
    public String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物资code
     */
    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 物资Id
     */
    public Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资Id
     */
    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 规格型号
     */
    public String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(String spec) {
        this.spec = spec;
    }
    /**
     * 计量单位
     */
    public String getUnit() {
        return unit;
    }

    /**
     * 计量单位
     */
    public void setUnit(String unit) {
        this.unit = unit;
    }
    /**
     * 资产id
     */
    public Long getAssetId() {
        return assetId;
    }

    /**
     * 资产id
     */
    public void setAssetId(Long assetId) {
        this.assetId = assetId;
    }
    /**
     * 0台车1周转材
     */
    public Integer getAssetType() {
        return assetType;
    }

    /**
     * 0台车1周转材
     */
    public void setAssetType(Integer assetType) {
        this.assetType = assetType;
    }
    /**
     * 台车/周转材
     */
    public String getAssetName() {
        return assetName;
    }

    /**
     * 台车/周转材
     */
    public void setAssetName(String assetName) {
        this.assetName = assetName;
    }
    /**
     * 编码
     */
    public String getAssetCode() {
        return assetCode;
    }

    /**
     * 编码
     */
    public void setAssetCode(String assetCode) {
        this.assetCode = assetCode;
    }
    /**
     * 组织Id
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织Id
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目id
     */
    public Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    /**
     * 承载量（吨)
     */
    public java.math.BigDecimal getTon() {
        return ton;
    }

    /**
     * 承载量（吨)
     */
    public void setTon(java.math.BigDecimal ton) {
        this.ton = ton;
    }
    /**
     * 在场数量
     */
    public java.math.BigDecimal getOnNum() {
        return onNum;
    }

    /**
     * 在场数量
     */
    public void setOnNum(java.math.BigDecimal onNum) {
        this.onNum = onNum;
    }
    /**
     * 处置数量
     */
    public java.math.BigDecimal getDealNum() {
        return dealNum;
    }

    /**
     * 处置数量
     */
    public void setDealNum(java.math.BigDecimal dealNum) {
        this.dealNum = dealNum;
    }
    /**
     * 处置单价
     */
    public java.math.BigDecimal getDealPrice() {
        return dealPrice;
    }

    /**
     * 处置单价
     */
    public void setDealPrice(java.math.BigDecimal dealPrice) {
        this.dealPrice = dealPrice;
    }
    /**
     * 处置金额
     */
    public java.math.BigDecimal getDealMoney() {
        return dealMoney;
    }

    /**
     * 处置金额
     */
    public void setDealMoney(java.math.BigDecimal dealMoney) {
        this.dealMoney = dealMoney;
    }
    /**
     * 0项目1公司
     */
    public Integer getBelongType() {
        return belongType;
    }

    /**
     * 0项目1公司
     */
    public void setBelongType(Integer belongType) {
        this.belongType = belongType;
    }
    /**
     * 资产归属类型
     */
    public Integer getAssetBelongType() {
        return assetBelongType;
    }

    /**
     * 资产归属类型
     */
    public void setAssetBelongType(Integer assetBelongType) {
        this.assetBelongType = assetBelongType;
    }
    /**
     * 资产归属机构id
     */
    public Long getBelongOrgId() {
        return belongOrgId;
    }

    /**
     * 资产归属机构id
     */
    public void setBelongOrgId(Long belongOrgId) {
        this.belongOrgId = belongOrgId;
    }
    /**
     * 资产归属机构名称
     */
    public String getBelongOrgName() {
        return belongOrgName;
    }

    /**
     * 资产归属机构名称
     */
    public void setBelongOrgName(String belongOrgName) {
        this.belongOrgName = belongOrgName;
    }
    
}
